import cv2

from robot_neck_fake.executor import FakeNeckExecutor

if __name__ == '__main__':
    c = FakeNeckExecutor()
    while True:
        frame = c.down()
        # Display the resulting frame
        cv2.imshow('frame', frame)

        # Exit if ESC key is pressed
        if cv2.waitKey(20) & 0xFF == 27:
            break





import cv2
from robot_core.executor.executor import Executor


class FakeNeckExecutor(Executor):
    # Start Capture
    cap = cv2.VideoCapture(1)

    # Get frame dimensions
    frame_width = cap.get(cv2.CAP_PROP_FRAME_WIDTH)
    frame_height = cap.get(cv2.CAP_PROP_FRAME_HEIGHT)

    def execute(self, **kwargs):
        if kwargs["command"] == "up":
            return self.up()
        elif kwargs["command"] == "down":
            return self.down()

        if kwargs["src"] is not None:
            cap = cv2.VideoCapture(kwargs["src"])

    def up(self):
        img = cv2.imread('up.png')
        img_height, img_width, _ = img.shape
        ret, frame = self.cap.read()
        frame_height, frame_width, _ = frame.shape
        x = (frame_width / 2) - (img_width / 2) - 50
        y = 70
        frame[y:y + img_height, x:x + img_width] = img
        return frame

    def down(self):
        img = cv2.imread('down.png')
        img_height, img_width, _ = img.shape
        ret, frame = self.cap.read()
        frame_height, frame_width, _ = frame.shape
        x = (frame_width / 2) - (img_width / 2) - 50
        y = frame_height - img_height - 10
        frame[y:y + img_height, x:x + img_width] = img
        return frame




from setuptools import setup, find_packages

setup(
    name='robot_neck_fake',
    version='0.0.3',
    packages=find_packages(),
    install_requires=[
        'imutils',
        'numpy',
        'opencv-python'
    ]
)
